@@ -15,6 +15,7 @@ from moodle_dl.download_service.path_tools import PathTools
 from moodle_dl.download_service.url_target import URLTarget
 from moodle_dl.download_service.downloader import Downloader
 from moodle_dl.moodle_connector.moodle_service import MoodleService
+from moodle_dl.moodle_connector.ssl_helper import configure_ssl_context
 
 
 class DownloadService:
@@ -96,6 +97,7 @@ class DownloadService:
             self.ssl_context = ssl._create_unverified_context()
         else:
             self.ssl_context = ssl.create_default_context(cafile=certifi.where())
+        configure_ssl_context(self.ssl_context)
         self.skip_cert_verify = skip_cert_verify
 
         # Prepopulate queue with any files that were given
