@@ -31,6 +31,7 @@ from moodle_dl.state_recorder.file import File
 from moodle_dl.state_recorder.course import Course
 from moodle_dl.download_service.path_tools import PathTools
 from moodle_dl.moodle_connector.request_helper import RequestHelper
+from moodle_dl.moodle_connector.ssl_helper import custom_session
 from moodle_dl.ydl_extractors.extractors import add_additional_extractors
 
 
@@ -79,8 +80,8 @@ class URLTarget(object):
         # Total downloaded.
         self.downloaded = 0
 
-        # For Youtube-dl errors
-        self.youtube_dl_failed_with_error = False
+        # For yt-dlp errors
+        self.yt_dlp_failed_with_error = False
 
     def add_progress(self, count: int, block_size: int, total_size: int):
         """
@@ -96,7 +97,7 @@ class URLTarget(object):
             total_size = self.file.content_filesize
 
         percent = 100
-        if total_size != 0:
+        if total_size > 0:
             percent = int(self.downloaded * 100 / total_size)
 
         self.thread_report[self.thread_id]['percentage'] = percent
@@ -208,7 +209,7 @@ class URLTarget(object):
 
     class YtLogger(object):
         """
-        Just a logger for Youtube-DL
+        Just a logger for yt-dlp
         """
 
         def __init__(self, url_target):
@@ -229,30 +230,30 @@ class URLTarget(object):
             if msg.find('ETA') >= 0:
                 return
             msg = self.clean_msg(msg)
-            logging.debug('T%s - youtube-dl Debug: %s', self.thread_id, msg)
+            logging.debug('T%s - yt-dlp Debug: %s', self.thread_id, msg)
             pass
 
         def warning(self, msg):
             msg = self.clean_msg(msg)
             if msg.find('Falling back') >= 0:
-                logging.debug('T%s - youtube-dl Warning: %s', self.thread_id, msg)
+                logging.debug('T%s - yt-dlp Warning: %s', self.thread_id, msg)
                 return
             if msg.find('Requested formats are incompatible for merge') >= 0:
-                logging.debug('T%s - youtube-dl Warning: %s', self.thread_id, msg)
+                logging.debug('T%s - yt-dlp Warning: %s', self.thread_id, msg)
                 return
-            logging.warning('T%s - youtube-dl Warning: %s', self.thread_id, msg)
+            logging.warning('T%s - yt-dlp Warning: %s', self.thread_id, msg)
 
         def error(self, msg):
             msg = self.clean_msg(msg)
             if msg.find('Unsupported URL') >= 0:
-                logging.debug('T%s - youtube-dl Error: %s', self.thread_id, msg)
+                logging.debug('T%s - yt-dlp Error: %s', self.thread_id, msg)
                 return
             if msg.find('no suitable InfoExtractor') >= 0:
-                logging.debug('T%s - youtube-dl Error: %s', self.thread_id, msg)
+                logging.debug('T%s - yt-dlp Error: %s', self.thread_id, msg)
                 return
             # This is a critical error, with high probability the link can be downloaded at a later time.
-            logging.error('T%s - youtube-dl Error: %s', self.thread_id, msg)
-            self.url_target.youtube_dl_failed_with_error = True
+            logging.error('T%s - yt-dlp Error: %s', self.thread_id, msg)
+            self.url_target.yt_dlp_failed_with_error = True
 
     def yt_hook(self, d):
         downloaded_bytes = d.get('downloaded_bytes', 0)
@@ -308,7 +309,7 @@ class URLTarget(object):
             final_filename = final_filename[rel_pos:]
         self.file.saved_to = final_filename
 
-    def is_blocked_for_youtube_dl(self, url_to_download: str):
+    def is_blocked_for_yt_dlp(self, url_to_download: str):
         url_parsed = urlparse.urlparse(url_to_download)
         if url_parsed.hostname.endswith('youtube.com') and url_parsed.path.startswith('/channel/'):
             # We do not want to download whole channels
@@ -382,7 +383,7 @@ class URLTarget(object):
         isHTML = False
         new_filename = ""
         total_bytes_estimate = -1
-        session = requests.Session()
+        session = custom_session()
 
         if cookies_path is not None:
             session.cookies = MozillaCookieJar(cookies_path)
@@ -495,7 +496,7 @@ class URLTarget(object):
                 self.success = True
                 return True
 
-        elif isHTML and not self.is_blocked_for_youtube_dl(url_to_download):
+        elif isHTML and not self.is_blocked_for_yt_dlp(url_to_download):
 
             filename_tmpl = self.filename + ' - %(title)s (%(id)s).%(ext)s'
             if self.file.content_type == 'description-url':
@@ -514,8 +515,8 @@ class URLTarget(object):
                 'addmetadata': True,
             }
 
-            youtube_dl_options = self.options.get('youtube_dl_options', {})
-            ydl_opts.update(youtube_dl_options)
+            yt_dlp_options = self.options.get('yt_dlp_options', {})
+            ydl_opts.update(yt_dlp_options)
 
             if cookies_path is not None and os.path.isfile(cookies_path):
                 ydl_opts.update({'cookiefile': cookies_path})
@@ -533,8 +534,8 @@ class URLTarget(object):
                 if idx_pw + 1 <= len(password_list):
                     ydl.params['videopassword'] = password_list[idx_pw]
 
-                self.youtube_dl_failed_with_error = False
-                # we restart youtube-dl, so we need to reset the return code
+                self.yt_dlp_failed_with_error = False
+                # we restart yt-dlp, so we need to reset the return code
                 ydl._download_retcode = 0  # pylint: disable=protected-access
                 try:
                     ydl_results = ydl.download([url_to_download])
@@ -551,32 +552,32 @@ class URLTarget(object):
                         break
                 except Exception as e:
                     logging.error(
-                        'T%s - Youtube-dl failed! Error: %s',
+                        'T%s - yt-dlp failed! Error: %s',
                         self.thread_id,
                         e,
                     )
-                    self.youtube_dl_failed_with_error = True
+                    self.yt_dlp_failed_with_error = True
                 idx_pw += 1
                 if idx_pw + 1 > len(password_list):
                     break
 
             # if we want we could save ydl.cookiejar (Also the cookiejar of moodle-dl)
 
-            if self.youtube_dl_failed_with_error is True and not self.options.get('ignore_ytdl_errors', False):
+            if self.yt_dlp_failed_with_error is True and not self.options.get('ignore_ytdl_errors', False):
                 if not delete_if_successful:
                     # cleanup the url-link file
                     try:
                         os.remove(self.file.saved_to)
                     except OSError as e:
                         logging.warning(
-                            'T%s - Could not delete %s after youtube-dl failed. Error: %s',
+                            'T%s - Could not delete %s after yt-dlp failed. Error: %s',
                             self.thread_id,
                             self.file.saved_to,
                             e,
                         )
                 self.success = False
                 raise RuntimeError(
-                    'Youtube-dl could not download the URL. For details see youtube-dl error messages in the log file. '
+                    'yt-dlp could not download the URL. For details see yt-dlp error messages in the log file. '
                     + 'You can ignore this error by running `moodle-dl --ignore-ytdl-errors` once.'
                 )
 
@@ -829,7 +830,7 @@ class URLTarget(object):
         self.thread_report[self.thread_id]['extra_totalsize'] = None
         self.thread_report[self.thread_id]['current_url'] = self.file.content_fileurl
         self.thread_report[self.thread_id]['external_dl'] = None
-        self.youtube_dl_failed_with_error = False
+        self.yt_dlp_failed_with_error = False
 
         try:
             logging.debug('T%s - Starting downloading of: %s', self.thread_id, self)
