@@ -100,8 +100,6 @@ class AssignmentsHandler:
         if self.version < 2016052300:
             return assignments
 
-        intro = '\rDownloading submission information'
-
         counter = 0
         total = 0
 
@@ -121,7 +119,15 @@ class AssignmentsHandler:
                 if len(shorted_assign_name) > 17:
                     shorted_assign_name = shorted_assign_name[:15] + '..'
 
-                print(intro + ' %3d/%3d [%-17s|%6s]\033[K' % (counter, total, shorted_assign_name, course_id), end='')
+                print(
+                    (
+                        '\r'
+                        + 'Downloading submission information'
+                        + f' {counter:3d}/{total:3d}'
+                        + f' [{shorted_assign_name:<17}|{course_id:6}]\033[K'
+                    ),
+                    end='',
+                )
 
                 submission = self.request_helper.post_REST('mod_assign_get_submission_status', data)
 
